Django Music Publisher
++++++++++++++++++++++

.. image:: https://travis-ci.com/matijakolaric-com/django-music-publisher.svg?branch=master
    :target: https://travis-ci.com/matijakolaric-com/django-music-publisher
    :alt: Build Status
.. image:: https://readthedocs.org/projects/django-music-publisher/badge/?version=latest
    :target: https://django-music-publisher.readthedocs.io/en/latest/
    :alt: Documentation Status
.. image:: https://coveralls.io/repos/github/matijakolaric-com/django-music-publisher/badge.svg?branch=master
    :target: https://coveralls.io/github/matijakolaric-com/django-music-publisher?branch=master
    :alt: Coverage Status
.. image:: https://img.shields.io/github/license/matijakolaric-com/django-music-publisher.svg
    :target: https://github.com/matijakolaric-com/django-music-publisher/blob/master/LICENSE
    :alt: License
.. image:: https://img.shields.io/pypi/v/django-music-publisher.svg
    :target: https://pypi.org/project/django-music-publisher/
    :alt: PYPI

Django-Music-Publisher (DMP) is open source software for original music publishers.
It is a tool for **managing metadata** for musical works and recordings,
including data about writers, recording and performing artists, albums and
music libraries.

It uses
`Common Works Registration (CWR) <https://matijakolaric.com/articles/1/>`_
for batch registration of musical works, versions 2.1 (stable) and 3.0
(experimental).

Installation to a cloud platform, free tier, requires no technical skills.

Documentation includes a detailed user manual and video tutorials.

Professional maintenance and user support are available.

* Docs: https://django-music-publisher.readthedocs.io/
* Code: https://github.com/matijakolaric-com/django-music-publisher/
* PYPI: https://pypi.org/project/django-music-publisher/
